single_evaluation_node_allowed

Function single_evaluation_node_allowed 

fn single_evaluation_node_allowed(node: &LogicalPlan) -> bool
Returns whether a plan node can occur on the scan path of a controlled PromQL single evaluation without changing which row is newest per series.